@@ -2,13 +2,14 @@ import importlib
 from abc import ABC
 from typing import Dict, Union
 
+from johnsnowlabs.py_models.lib_version import LibVersion
 from johnsnowlabs.py_models.url_dependency import UrlDependency
 from johnsnowlabs.utils.enums import *
-from johnsnowlabs.py_models.lib_version import LibVersion
 
 
 def is_spark_version_env(spark_version: str) -> bool:
     import pyspark
+
     env_spark_version = pyspark.__version__[0:-2].replace(".", "")
     return spark_version in env_spark_version
 
@@ -19,7 +20,7 @@ def try_import_lib(lib: str, print_failure=False):
         return True
     except Exception as _:
         if print_failure:
-            print(f'Failed to import {lib}. Seems not installed.')
+            print(f"Failed to import {lib}. Seems not installed.")
 
 
 class Py4JJslLibDependencyResolverABC(ABC):
@@ -38,6 +39,7 @@ class Py4JJslLibDependencyResolverABC(ABC):
 
 
     """
+
     has_gpu_jars: bool = False
     has_cpu_jars: bool = False
     has_m1_jar: bool = False
@@ -46,42 +48,53 @@ class Py4JJslLibDependencyResolverABC(ABC):
     lib_version: LibVersion
     product_name: ProductName
     # key = Supported Spark Version, Value = Dict  with key=m1/cpu/gpu and value = URL/ URL formatable with secret
-    compatible_spark_to_jar_map: Dict[SparkVersion,
-                                      Dict[JvmHardwareTarget, UrlDependency]]
+    compatible_spark_to_jar_map: Dict[
+        SparkVersion, Dict[JvmHardwareTarget, UrlDependency]
+    ]
 
     # key = Supported Spark Version, Value = Dict with key=tar/wheel and value = URL? URL formatable with secret
-    compatible_spark_to_py_map: Dict[SparkVersion,
-                                     Dict[PyInstallTypes, UrlDependency]]
+    compatible_spark_to_py_map: Dict[SparkVersion, Dict[PyInstallTypes, UrlDependency]]
 
     @classmethod
-    def get_dependency_url(cls,
-                           install_type: Union[JvmHardwareTarget, PyInstallTypes],
-                           spark_version_to_match: Optional[Union[str, LibVersion]],
-                           secret: Optional[str] = None,
-                           ) -> UrlDependency:
+    def get_dependency_url(
+        cls,
+        install_type: Union[JvmHardwareTarget, PyInstallTypes],
+        spark_version_to_match: Optional[Union[str, LibVersion]],
+        secret: Optional[str] = None,
+    ) -> UrlDependency:
 
         if install_type in PyInstallTypes:
             return cls.get_py_urls(
-                secret=secret, spark_version_to_match=spark_version_to_match, install_type=install_type)
+                secret=secret,
+                spark_version_to_match=spark_version_to_match,
+                install_type=install_type,
+            )
         elif install_type in JvmHardwareTarget:
             return cls.get_jar_urls(
-                secret=secret, spark_version_to_match=spark_version_to_match, hardware_target=install_type)
+                secret=secret,
+                spark_version_to_match=spark_version_to_match,
+                hardware_target=install_type,
+            )
         else:
-            raise ValueError(f'Invalid Install type = {install_type} must be JvmHardwareTarget or PyInstallType')
+            raise ValueError(
+                f"Invalid Install type = {install_type} must be JvmHardwareTarget or PyInstallType"
+            )
 
     @classmethod
-    def get_url_from_compat_map(cls,
-                                compat_map:
-                                Dict[SparkVersion,
-                                     Dict[Union[JvmHardwareTarget, PyInstallTypes],
-                                          UrlDependency]],
-                                install_type: Union[JvmHardwareTarget, PyInstallTypes],
-                                spark_version_to_match: Optional[Union[str, LibVersion]],
-                                secret: Optional[str] = None,
-                                suffix: str = '',
-                                ) -> UrlDependency:
+    def get_url_from_compat_map(
+        cls,
+        compat_map: Dict[
+            SparkVersion, Dict[Union[JvmHardwareTarget, PyInstallTypes], UrlDependency]
+        ],
+        install_type: Union[JvmHardwareTarget, PyInstallTypes],
+        spark_version_to_match: Optional[Union[str, LibVersion]],
+        secret: Optional[str] = None,
+        suffix: str = "",
+    ) -> UrlDependency:
 
-        spark_version_to_match = cls.resolve_to_spark_lib_version(spark_version_to_match)
+        spark_version_to_match = cls.resolve_to_spark_lib_version(
+            spark_version_to_match
+        )
         matching_jsl_spark_release = None
         for compatible_spark in compat_map.keys():
             compatible_spark: SparkVersion = compatible_spark
@@ -92,75 +105,98 @@ class Py4JJslLibDependencyResolverABC(ABC):
             # Todo make special type of exception and catch?
             # TODO nicer print
             raise Exception(
-                f'{cls.product_name.value} does not have any install candidates for'
-                f' pyspark=={spark_version_to_match.as_str()} \n'
-                f'Please install one of the following Pyspark Versions : {1} TODO')
+                f"{cls.product_name.value} does not have any install candidates for"
+                f" pyspark=={spark_version_to_match.as_str()} \n"
+                f"Please install one of the following Pyspark Versions : {1} TODO"
+            )
 
         if cls.has_secret:
             if settings.enforce_versions:
                 url = compat_map[matching_jsl_spark_release][install_type].url.format(
-                    secret=secret, lib_version=cls.lib_version.as_str())
+                    secret=secret, lib_version=cls.lib_version.as_str()
+                )
             else:
                 # Read Version from secret
                 url = compat_map[matching_jsl_spark_release][install_type].url.format(
-                    secret=secret, lib_version=secret.split('-')[0])
+                    secret=secret, lib_version=secret.split("-")[0]
+                )
 
         else:
             if settings.enforce_versions:
                 url = compat_map[matching_jsl_spark_release][install_type].url.format(
-                    lib_version=cls.lib_version.as_str())
+                    lib_version=cls.lib_version.as_str()
+                )
             else:
                 # read from updated settings instead of already instantiated Objects, which will not reflect setting updates
                 url = compat_map[matching_jsl_spark_release][install_type].url.format(
-                    lib_version=LatestCompatibleProductVersion.from_settings(cls.product_name))
-                url.replace(cls.lib_version.as_str(), LatestCompatibleProductVersion.from_settings(cls.product_name))
+                    lib_version=LatestCompatibleProductVersion.from_settings(
+                        cls.product_name
+                    )
+                )
+                url.replace(
+                    cls.lib_version.as_str(),
+                    LatestCompatibleProductVersion.from_settings(cls.product_name),
+                )
 
         # NAME-VERSION-INSTALL_TYPE-for-spark-SPARK_VERSION-.[jar/tar/wheel]
-        name = f'{cls.product_name.value}-{cls.lib_version.as_str()}' \
-               f'-{install_type.name}-for-spark-{matching_jsl_spark_release.value.as_str()}.{suffix}'
-        return UrlDependency(url=url,
-                             dependency_type=install_type,
-                             spark_version=matching_jsl_spark_release,
-                             dependency_version=cls.lib_version,
-                             file_name=name,
-                             product_name=cls.product_name.value)
+        name = (
+            f"{cls.product_name.value}-{cls.lib_version.as_str()}"
+            f"-{install_type.name}-for-spark-{matching_jsl_spark_release.value.as_str()}.{suffix}"
+        )
+        return UrlDependency(
+            url=url,
+            dependency_type=install_type,
+            spark_version=matching_jsl_spark_release,
+            dependency_version=cls.lib_version,
+            file_name=name,
+            product_name=cls.product_name.value,
+        )
 
     @classmethod
-    def get_jar_urls(cls,
-                     secret: Optional[str] = None,
-                     spark_version_to_match: Optional[Union[str, LibVersion]] = None,
-                     hardware_target: JvmHardwareTarget = JvmHardwareTarget.cpu,
-                     ) -> UrlDependency:
+    def get_jar_urls(
+        cls,
+        secret: Optional[str] = None,
+        spark_version_to_match: Optional[Union[str, LibVersion]] = None,
+        hardware_target: JvmHardwareTarget = JvmHardwareTarget.cpu,
+    ) -> UrlDependency:
         """
         Get jar URL location for hardware target.
         Jar loc formats with secret+jsl_lib_version for licensed and
          only with jsl-lib_version for open source
         """
         if hardware_target == JvmHardwareTarget.cpu and not cls.has_cpu_jars:
-            raise Exception(f'{cls.product_name.value} has no CPU Jars!')
+            raise Exception(f"{cls.product_name.value} has no CPU Jars!")
 
         if hardware_target == JvmHardwareTarget.gpu and not cls.has_gpu_jars:
-            raise Exception(f'{cls.product_name.value} has no GPU Jars!')
+            raise Exception(f"{cls.product_name.value} has no GPU Jars!")
 
         if hardware_target == JvmHardwareTarget.m1 and not cls.has_m1_jar:
-            raise Exception(f'{cls.product_name.value} has no M1 Jars!')
+            raise Exception(f"{cls.product_name.value} has no M1 Jars!")
 
-        return cls.get_url_from_compat_map(compat_map=cls.compatible_spark_to_jar_map,
-                                           install_type=hardware_target,
-                                           spark_version_to_match=spark_version_to_match,
-                                           secret=secret, suffix='jar')
+        return cls.get_url_from_compat_map(
+            compat_map=cls.compatible_spark_to_jar_map,
+            install_type=hardware_target,
+            spark_version_to_match=spark_version_to_match,
+            secret=secret,
+            suffix="jar",
+        )
 
     @classmethod
-    def get_py_urls(cls,
-                    secret: Optional[str] = None,
-                    spark_version_to_match: Optional[Union[str, LibVersion]] = None,
-                    install_type: PyInstallTypes = PyInstallTypes.wheel) -> UrlDependency:
+    def get_py_urls(
+        cls,
+        secret: Optional[str] = None,
+        spark_version_to_match: Optional[Union[str, LibVersion]] = None,
+        install_type: PyInstallTypes = PyInstallTypes.wheel,
+    ) -> UrlDependency:
         if not cls.has_py_install:
-            raise Exception(f'{cls.product_name.value} has no Py Dependencies!')
-        return cls.get_url_from_compat_map(compat_map=cls.compatible_spark_to_py_map,
-                                           install_type=install_type,
-                                           spark_version_to_match=spark_version_to_match,
-                                           secret=secret, suffix=install_type.value)
+            raise Exception(f"{cls.product_name.value} has no Py Dependencies!")
+        return cls.get_url_from_compat_map(
+            compat_map=cls.compatible_spark_to_py_map,
+            install_type=install_type,
+            spark_version_to_match=spark_version_to_match,
+            secret=secret,
+            suffix=install_type.value,
+        )
 
     @classmethod
     def resolve_to_spark_lib_version(cls, spark_version_to_match) -> LibVersion:
@@ -186,13 +222,15 @@ class Py4JJslLibDependencyResolverABC(ABC):
         # 3. Check if is spark_version_to_match is some other type, if yes raise exception, should not happen
         elif spark_version_to_match:
             raise ValueError(
-                f'Invalid Type for spark_version_to_match, '
-                f'must be either str in format A.B.C, None or Libversion'
-                f'But type is ={type(spark_version_to_match)}')
+                f"Invalid Type for spark_version_to_match, "
+                f"must be either str in format A.B.C, None or Libversion"
+                f"But type is ={type(spark_version_to_match)}"
+            )
 
         # 4. Check if is pyspark is installed
-        elif try_import_lib('pyspark'):
+        elif try_import_lib("pyspark"):
             import pyspark
+
             # TODO check product wide compatibility for pre-installed pyspark --> make helper method for that
             return LibVersion(pyspark.__version__)
         # 5. Return the latest compatible pyspark if no other method  resolves
